REST API v1
***********

This is v1 API based of Django. The second version :ref:`restapi2` is under construction.

.. toctree::
   :maxdepth: 2
   :titlesonly:

   Objective
   Configuration
   Endpoint
   Methods
   General parameters/index
   Request
   Response/index
   Resources/index
   Errors
   Examples
   Useful links <Useful_links>
